#ifndef EO_BASE_EO_HH
#define EO_BASE_EO_HH
#include <Eo.h>

extern "C" {
#include "eo_base.eo.h"
}
#include <Eina.hh>
#include <Eo.hh>
namespace eo { 
struct Base;
} 
namespace efl { namespace eo { template<> struct is_eolian_object< ::eo::Base> : ::std::true_type {}; } }

namespace eo_cxx {
namespace eo { 
struct Base {
   ::efl::eolian::return_traits< ::eo::Base>::type parent_get() const;
   ::efl::eolian::return_traits<void>::type parent_set( ::efl::eolian::in_traits< ::eo::Base>::type parent) const;
   ::efl::eolian::return_traits< ::efl::eina::string_view>::type name_get() const;
   ::efl::eolian::return_traits<void>::type name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const;
   ::efl::eolian::return_traits< ::efl::eina::string_view>::type comment_get() const;
   ::efl::eolian::return_traits<void>::type comment_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type comment) const;
   ::efl::eolian::return_traits<int>::type event_global_freeze_count_get() const;
   ::efl::eolian::return_traits<int>::type event_freeze_count_get() const;
   ::efl::eolian::return_traits<bool>::type finalized_get() const;
   ::efl::eolian::return_traits<void*>::type key_data_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const;
   ::efl::eolian::return_traits<void>::type key_data_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits<void const*>::type data) const;
   ::efl::eolian::return_traits< ::eo::Base>::type key_ref_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const;
   ::efl::eolian::return_traits<void>::type key_ref_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits< ::eo::Base>::type objdata) const;
   ::efl::eolian::return_traits< ::eo::Base>::type key_wref_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const;
   ::efl::eolian::return_traits<void>::type key_wref_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits< ::eo::Base>::type objdata) const;
   ::efl::eolian::return_traits< ::efl::eina::value_view&>::type key_value_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const;
   ::efl::eolian::return_traits<void>::type key_value_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits< ::efl::eina::value_view const&>::type value) const;
   ::efl::eolian::return_traits<void>::type del() const;
   ::efl::eolian::return_traits< ::eo::Base>::type provider_find( ::efl::eolian::in_traits< ::eo::Base>::type klass) const;
   ::efl::eolian::return_traits< ::eo::Base>::type constructor() const;
   ::efl::eolian::return_traits<void>::type destructor() const;
   ::efl::eolian::return_traits< ::eo::Base>::type finalize() const;
   ::efl::eolian::return_traits< ::eo::Base>::type name_find( ::efl::eolian::in_traits< ::efl::eina::string_view>::type search) const;
   ::efl::eolian::return_traits<void>::type wref_add( ::efl::eolian::in_traits< ::eo::Base&>::type wref) const;
   ::efl::eolian::return_traits<void>::type wref_del( ::efl::eolian::in_traits< ::eo::Base&>::type wref) const;
   ::efl::eolian::return_traits<void>::type event_thaw() const;
   ::efl::eolian::return_traits<void>::type event_freeze() const;
   ::efl::eolian::return_traits<void>::type event_global_thaw() const;
   ::efl::eolian::return_traits<void>::type event_global_freeze() const;
   ::efl::eolian::return_traits<bool>::type event_callback_priority_add( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits<Eo_Callback_Priority>::type priority,  ::efl::eolian::in_traits<Eo_Event_Cb>::type cb,  ::efl::eolian::in_traits<void const*>::type data) const;
   ::efl::eolian::return_traits<bool>::type event_callback_del( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits<Eo_Event_Cb>::type func,  ::efl::eolian::in_traits<void const*>::type user_data) const;
   ::efl::eolian::return_traits<bool>::type event_callback_array_priority_add( ::efl::eolian::in_traits<Eo_Callback_Array_Item const&>::type array,  ::efl::eolian::in_traits<Eo_Callback_Priority>::type priority,  ::efl::eolian::in_traits<void const*>::type data) const;
   ::efl::eolian::return_traits<bool>::type event_callback_array_del( ::efl::eolian::in_traits<Eo_Callback_Array_Item const&>::type array,  ::efl::eolian::in_traits<void const*>::type user_data) const;
   ::efl::eolian::return_traits<bool>::type event_callback_call( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits<void*>::type event_info) const;
   ::efl::eolian::return_traits<void>::type event_callback_stop() const;
   ::efl::eolian::return_traits<void>::type event_callback_forwarder_add( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits< ::eo::Base>::type new_obj) const;
   ::efl::eolian::return_traits<void>::type event_callback_forwarder_del( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits< ::eo::Base>::type new_obj) const;
   ::efl::eolian::return_traits<void>::type dbg_info_get( ::efl::eolian::in_traits<Eo_Dbg_Info const&>::type root_node) const;
   ::efl::eolian::return_traits< ::efl::eina::iterator< ::eo::Base>>::type children_iterator_new() const;
   ::efl::eolian::return_traits<bool>::type composite_attach( ::efl::eolian::in_traits< ::eo::Base>::type comp_obj) const;
   ::efl::eolian::return_traits<bool>::type composite_detach( ::efl::eolian::in_traits< ::eo::Base>::type comp_obj) const;
   ::efl::eolian::return_traits<bool>::type composite_part_is() const;
   static Eo_Class const* _eo_class()
   {
      return EO_BASE_CLASS;
   }
   Eo* _eo_ptr() const { return *(Eo**)this; }
   operator ::eo::Base() const;
   operator ::eo::Base&();
   operator ::eo::Base const&() const;
   /// @cond LOCAL
    ::efl::eolian::address_of_operator<Base> operator&() { return {this}; }
    ::efl::eolian::address_of_operator<Base const > operator&() const { return {this}; }
   /// @endcond
};
} 
}
namespace eo { 
struct Base : ::efl::eo::concrete
{
   explicit Base( ::Eo* eo)
      : ::efl::eo::concrete(eo) {}
   explicit Base(std::nullptr_t)
      : ::efl::eo::concrete(nullptr) {}
   Base(Base const& other) = default;
   Base(Base&& other) = default;
   Base& operator=(Base const& other) = default;
   Base& operator=(Base&& other) = default;
   Base()
   {
      ::efl::eolian::do_eo_add( ::efl::eo::concrete::_eo_raw, ::efl::eo::concrete{nullptr}, _eo_class());
   }
   Base( ::efl::eo::concrete parent)
   {
      ::efl::eolian::do_eo_add( ::efl::eo::concrete::_eo_raw, parent, _eo_class());
   }
   template <typename F> Base(F f, typename ::std::enable_if< ::efl::eolian::is_callable<F>::value>::type* = 0)
   {
      ::efl::eolian::do_eo_add( ::efl::eo::concrete::_eo_raw, ::efl::eo::concrete{nullptr}, _eo_class(), f);
   }
   ::efl::eolian::return_traits< ::eo::Base>::type parent_get() const;
   ::efl::eolian::return_traits<void>::type parent_set( ::efl::eolian::in_traits< ::eo::Base>::type parent) const;
   ::efl::eolian::return_traits< ::efl::eina::string_view>::type name_get() const;
   ::efl::eolian::return_traits<void>::type name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const;
   ::efl::eolian::return_traits< ::efl::eina::string_view>::type comment_get() const;
   ::efl::eolian::return_traits<void>::type comment_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type comment) const;
   ::efl::eolian::return_traits<int>::type event_global_freeze_count_get() const;
   ::efl::eolian::return_traits<int>::type event_freeze_count_get() const;
   ::efl::eolian::return_traits<bool>::type finalized_get() const;
   ::efl::eolian::return_traits<void*>::type key_data_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const;
   ::efl::eolian::return_traits<void>::type key_data_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits<void const*>::type data) const;
   ::efl::eolian::return_traits< ::eo::Base>::type key_ref_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const;
   ::efl::eolian::return_traits<void>::type key_ref_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits< ::eo::Base>::type objdata) const;
   ::efl::eolian::return_traits< ::eo::Base>::type key_wref_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const;
   ::efl::eolian::return_traits<void>::type key_wref_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits< ::eo::Base>::type objdata) const;
   ::efl::eolian::return_traits< ::efl::eina::value_view&>::type key_value_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const;
   ::efl::eolian::return_traits<void>::type key_value_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits< ::efl::eina::value_view const&>::type value) const;
   ::efl::eolian::return_traits<void>::type del() const;
   ::efl::eolian::return_traits< ::eo::Base>::type provider_find( ::efl::eolian::in_traits< ::eo::Base>::type klass) const;
   ::efl::eolian::return_traits< ::eo::Base>::type constructor() const;
   ::efl::eolian::return_traits<void>::type destructor() const;
   ::efl::eolian::return_traits< ::eo::Base>::type finalize() const;
   ::efl::eolian::return_traits< ::eo::Base>::type name_find( ::efl::eolian::in_traits< ::efl::eina::string_view>::type search) const;
   ::efl::eolian::return_traits<void>::type wref_add( ::efl::eolian::in_traits< ::eo::Base&>::type wref) const;
   ::efl::eolian::return_traits<void>::type wref_del( ::efl::eolian::in_traits< ::eo::Base&>::type wref) const;
   ::efl::eolian::return_traits<void>::type event_thaw() const;
   ::efl::eolian::return_traits<void>::type event_freeze() const;
   ::efl::eolian::return_traits<void>::type event_global_thaw() const;
   ::efl::eolian::return_traits<void>::type event_global_freeze() const;
   ::efl::eolian::return_traits<bool>::type event_callback_priority_add( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits<Eo_Callback_Priority>::type priority,  ::efl::eolian::in_traits<Eo_Event_Cb>::type cb,  ::efl::eolian::in_traits<void const*>::type data) const;
   ::efl::eolian::return_traits<bool>::type event_callback_del( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits<Eo_Event_Cb>::type func,  ::efl::eolian::in_traits<void const*>::type user_data) const;
   ::efl::eolian::return_traits<bool>::type event_callback_array_priority_add( ::efl::eolian::in_traits<Eo_Callback_Array_Item const&>::type array,  ::efl::eolian::in_traits<Eo_Callback_Priority>::type priority,  ::efl::eolian::in_traits<void const*>::type data) const;
   ::efl::eolian::return_traits<bool>::type event_callback_array_del( ::efl::eolian::in_traits<Eo_Callback_Array_Item const&>::type array,  ::efl::eolian::in_traits<void const*>::type user_data) const;
   ::efl::eolian::return_traits<bool>::type event_callback_call( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits<void*>::type event_info) const;
   ::efl::eolian::return_traits<void>::type event_callback_stop() const;
   ::efl::eolian::return_traits<void>::type event_callback_forwarder_add( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits< ::eo::Base>::type new_obj) const;
   ::efl::eolian::return_traits<void>::type event_callback_forwarder_del( ::efl::eolian::in_traits<Eo_Event_Description const&>::type desc,  ::efl::eolian::in_traits< ::eo::Base>::type new_obj) const;
   ::efl::eolian::return_traits<void>::type dbg_info_get( ::efl::eolian::in_traits<Eo_Dbg_Info const&>::type root_node) const;
   ::efl::eolian::return_traits< ::efl::eina::iterator< ::eo::Base>>::type children_iterator_new() const;
   ::efl::eolian::return_traits<bool>::type composite_attach( ::efl::eolian::in_traits< ::eo::Base>::type comp_obj) const;
   ::efl::eolian::return_traits<bool>::type composite_detach( ::efl::eolian::in_traits< ::eo::Base>::type comp_obj) const;
   ::efl::eolian::return_traits<bool>::type composite_part_is() const;
   static Eo_Class const* _eo_class()
   {
      return EO_BASE_CLASS;
   }
   Eo* _eo_ptr() const { return *(Eo**)this; }
   static struct callback_add_event
   {
      static Eo_Event_Description const* description()
      { return EO_EVENT_CALLBACK_ADD; }
      typedef void parameter_type;
   } const callback_add_event;
   static struct callback_del_event
   {
      static Eo_Event_Description const* description()
      { return EO_EVENT_CALLBACK_DEL; }
      typedef void parameter_type;
   } const callback_del_event;
   static struct del_event
   {
      static Eo_Event_Description const* description()
      { return EO_EVENT_DEL; }
      typedef void parameter_type;
   } const del_event;
   /// @cond LOCAL
    ::efl::eolian::address_of_operator<Base> operator&() { return {this}; }
    ::efl::eolian::address_of_operator<Base const > operator&() const { return {this}; }
   /// @endcond
};
static_assert(sizeof(Base) == sizeof(Eo*), "");
static_assert(std::is_standard_layout<Base>::value, "");
} 
#include "eo_base.eo.impl.hh"
#endif
